library(gnlm)
library(repeated)

data <- read.table("animal.dat",skip=5)
train <- codes(gl(2,8,16))==1
stimulus <- codes(gl(2,4,16))==1
y <- list()
for(i in 1:ncol(data)){
	y <- c(y,list(cbind(c(data[1:10,i],data[11:20,i][data[11:20,i]>0]),
		1:(10+length(data[11:20,i][data[11:20,i]>0])))))}
yb <- restovec(y,total=20)
y <- restovec(y)
reps <- rmna(y,ccov=tcctomat(~train+stimulus))
repsb <- rmna(yb,ccov=tcctomat(~train+stimulus))
# trick to get individual data for overdispersion instead
#	of clustering with gnlmm
times <- as.vector(times(reps))
train <- as.vector(covariates(tcctomat(~train))[covind(reps)])
stimulus <- as.vector(covariates(tcctomat(~stimulus))[covind(reps)])
reps1 <- rmna(restovec(response(reps)),ccov=tcctomat(~train+stimulus+times))
repsb1 <- rmna(restovec(response(reps),totals=rep(20,210)),
	ccov=tcctomat(~train+stimulus+times))

if(interactive()){
postscript("animal0.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(y,nind=1,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i,pch=i+20,add=T)
plot(y,nind=5,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i+4,pch=i+20,add=T)
plot(y,nind=9,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="Successes",main="Pre-trained - Bell")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i+8,pch=i+20,add=T)
plot(y,nind=13,pch=1,yaxt="n",xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="",main="Pre-trained - Light")
axis(2,c(0,5,10,15,20))
for(i in 2:4)plot(y,nind=i+12,pch=i+20,add=T)
dev.off()
}

mu1a <- function(p) p[1]+p[2]*times+p[3]*stimulus
mu1ai <- function(p) p[1]+p[2]*times+p[3]*stimulus+p[4]*stimulus*times
mu1ali <- function(p){
	tmp <- exp(p[1]+p[2]*times+p[3]*stimulus+p[4]*stimulus*times)
	tmp/(1+tmp)}
mu1lli <- function(p) exp(-exp(p[1]+p[2]*times+p[3]*stimulus+
	p[4]*stimulus*times))
mu3l <- function(p) {
	tmp <- exp(p[1]+p[2]*times+p[3]*stimulus)
	20*tmp/(1+tmp)}
mu3li <- function(p) {
	tmp <- exp(p[1]+p[2]*times+p[3]*stimulus+p[4]*times*stimulus)
	20*tmp/(1+tmp)}
mu3clli <- function(p) 20*(1-exp(-exp(p[1]+p[2]*times+p[3]*stimulus+
	p[4]*times*stimulus)))

gnlr(repsb,dist="binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0))
gnlr(repsb,dist="beta binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0),psh=1)
gnlr(repsb,dist="mult binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0),psh=1)
gnlr(repsb,dist="double binomial",mu=mu1ali,pmu=c(-0.8,0.1,0.4,0),psh=-2)
gnlmm(repsb1,dist="binomial",mu=mu1ali,pmu=c(-3.6,0.46,1.83,0),psd=1.2,
	points=3)

gnlr(repsb,dist="binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0))
gnlr(repsb,dist="beta binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psh=1)
gnlr(repsb,dist="mult binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psh=1)
gnlr(repsb,dist="double binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psh=1)
gnlmm(repsb1,dist="binomial",mu=mu1lli,pmu=c(1.9,-0.3,-1.1,0),psd=1.2,points=3)

gar(repsb,dist="binomial",mu=mu1ai,preg=c(-2,0.3,0,0),pdep=0.1,link="logit")
gar(repsb,dist="beta binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	 psh=1,pdep=0.5,link="logit")
gar(repsb,dist="mult binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	 psh=1,pdep=0.1,link="logit")
gar(repsb,dist="double binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	 psh=0.1,pdep=0.1,link="logit")

gar(repsb,dist="binomial",mu=mu1ai,preg=c(1.6,-0.3,0,0),pdep=0.1,
	link="loglog")
gar(repsb,dist="beta binomial",mu=mu1ai,preg=c(-2,0.3,0,0),
	psh=1,pdep=0.5,link="loglog")
gar(repsb,dist="mult binomial",mu=mu1ai,preg=c(2,-0.4,-0.1,0),
	psh=1,pdep=0.1,link="loglog")
gar(repsb,dist="double binomial",mu=mu1ai,preg=c(2,-0.4,-0.1,0),
	psh=0.1,pdep=0.1,link="loglog")

print(zdb2 <- gar(repsb,dist="double binomial",mu=mu1a,preg=c(-4,0.6,2),
	 psh=0.3,pdep=0.03,link="logit"))

if(interactive()){
mu1ap <- function(p,times,stimulus) exp(p[1]+p[2]*times+p[3]*stimulus)/
      (1+exp(p[1]+p[2]*times+p[3]*stimulus))*20
postscript("animal1b.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(iprofile(zdb2),nind=1:2,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,1))
plot(iprofile(zdb2),nin=5:6,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,0))
plot(iprofile(zdb2),nind=9:10,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="Successes",main="Pre-trained - Bell",
	yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,1))
plot(iprofile(zdb2),nind=13:14,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="",main="Pre-trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mu1ap(zdb2$coef,1:20,0))
dev.off()
}

gnlr(reps,"Poisson",mu=mu3li,pmu=c(-3.8,0.6,0.4,0))
gnlr(reps,"negative binomial",mu=mu3li,pmu=c(-3.8,0.6,0.4,0),psh=1.7)
gnlr(reps,"mult Poisson",mu=mu3li,pmu=c(-3.9,0.6,0.5,0),psh=-0.1)
gnlr(reps,"double Poisson",mu=mu3li,pmu=c(-3.9,0.6,0.5,0),psh=-1)
gnlmm(reps1,"Poisson",mu=mu3li,pmu=c(-4.51,0.63,2.36,0),psd=0.87,
	points=3)

gnlr(reps,"Poisson",mu=mu3clli,pmu=c(-3.8,0.6,0.4,0))
gnlr(reps,"negative binomial",mu=mu3clli,pmu=c(-3.8,0.6,0.4,0),psh=1.7)
gnlr(reps,"mult Poisson",mu=mu3clli,pmu=c(-3.9,0.6,0.5,0),psh=-0.1)
gnlr(reps,"double Poisson",mu=mu3clli,pmu=c(-3.9,0.6,0.5,0),psh=-1)
gnlmm(reps1,"Poisson",mu=mu3clli,pmu=c(-4.01,0.49,1.96,0),psd=0.85,
	points=3)

gar(reps,dist="Poisson",mu=mu3li,preg=c(-3.8,0.6,0.4,0),pdep=0.1)
gar(reps,dist="negative",mu=mu3li,preg=c(-3.5,0.44,0.4,0.4),
	shape=~a*mu,shfn=T,psh=0.7,pdep=0.1)
gar(reps,dist="mult Poisson",mu=mu3li,preg=c(0.15,0.2,0.8,0),psh=0.7,pdep=0.9)
print(zdpl <- gar(reps,dist="double Poisson",mu=mu3li,preg=c(0.15,0.2,0.8,0),
	psh=0.7,pdep=0.9))

gar(reps,dist="Poisson",mu=mu3clli,preg=c(0,0.03,0,0),pdep=0.1)
gar(reps,dist="negative",mu=mu3clli,preg=c(0.15,0.2,0.8,0),
	shape=~a*mu,shfn=T,psh=0.7,pdep=0.9)
gar(reps,dist="mult Poisson",mu=mu3clli,preg=c(0.15,0.2,0.8,0),psh=0.7,pdep=0.9)
gar(reps,dist="double Poisson",mu=mu3clli,preg=c(-3.3,0.4,0.5,0),psh=0.7,pdep=0.9)

if(interactive()){
mucll <- function(p,times,stimulus) 20*(1-exp(-exp(p[1]+p[2]*times+
	p[3]*stimulus)))
postscript("animal1.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(iprofile(zdpl),nind=1:2,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mucll(zdpl$coef,1:20,1))
plot(iprofile(zdpl),nind=5:6,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mucll(zdpl$coef,1:20,0))
plot(iprofile(zdpl),nind=9:10,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="Successes",main="Pre-trained - Bell",
	yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mucll(zdpl$coef,1:20,1))
plot(iprofile(zdpl),nind=13:14,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="",main="Pre-trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,mucll(zdpl$coef,1:20,0))
dev.off()
}

# Chapter 10
kalcount(reps,ccov=~stimulus,preg=c(0,0),pdep=0.5,dep="serial")
print(zw <- kalcount(reps,int="Weibull",ccov=~stimulus,preg=c(0,0),
	pdep=0.5,psh=2,dep="serial"))
print(zgl <- kalcount(reps,int="gen log",ccov=~stimulus,preg=c(1,-0.6),
	pdep=0.5,psh=0.05,dep="serial",pinter=0))

if(interactive()){
muzl <- function(p,times,stimulus) exp(p[5])*exp(p[1]+p[2]*stimulus)*
	(times/exp(p[1]+p[2]*stimulus))^(exp(p[5])-1)
postscript("animal2.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(iprofile(zw),nind=1:2,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzl(zw$coef,1:20,1))
plot(iprofile(zw),nind=5:6,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzl(zw$coef,1:20,0))
plot(iprofile(zw),nind=9:10,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="Successes",main="Pre-trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzl(zw$coef,1:20,1))
plot(iprofile(zw),nind=13:14,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="",main="Pre-trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzl(zw$coef,1:20,0))
dev.off()
muzgl <- function(p,times,stimulus) 1/(exp(p[5])+exp(-(p[1]+p[2]*stimulus)*
	times+p[6]))
postscript("animal3.eps")
par(mfrow=c(2,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(iprofile(zgl),nind=1:2,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="Successes",main="Not trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzgl(zgl$coef,1:20,1))
plot(iprofile(zgl),nind=5:6,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="",ylab="",main="Not trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzgl(zgl$coef,1:20,0))
plot(iprofile(zgl),nind=9:10,lty=c(3,2),pch=c(21,22),xlim=c(0,20),ylim=c(0,25),
	xlab="Trial",ylab="Successes",main="Pre-trained - Bell",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzgl(zgl$coef,1:20,1))
plot(iprofile(zgl),nind=13:14,lty=c(3,2),pch=c(21,22),xlim=c(0,20),
	ylim=c(0,25),xlab="Trial",ylab="",main="Pre-trained - Light",yaxt="n")
axis(2,c(0,5,10,15,20))
lines(1:20,muzgl(zgl$coef,1:20,0))
dev.off()
}

kalcount(reps,mu=mu3l,ptvc=c(-3.8,-0.1,-0.6),pinit=1,pdep=0.5,dep="serial")
kalcount(reps,int="Weibull",mu=mu3l,ptvc=c(-2.7,0.02,-0.03),
	pinit=0.6,pdep=0.5,psh=2,dep="serial")
