library(repeated)

resp <- read.table("epilepti.dat",skip=6)
colnames(resp) <- c("W2","W4","W6","W8","Treatment","Baseline","Age")
attach(resp)
lag1 <- cbind(Baseline/4,W2,W4,W6)
reps <- rmna(restovec(resp[,1:4],times=c(2,4,6,8)),
	ccov=tcctomat(~Baseline+Age),tvcov=tvctomat(lag1))

y <- response(reps)
y1 <- covariates(reps,name="lag1")
treatment <- rep(Treatment,rep(4,59))
age <- rep(Age,rep(4,59))
age2 <- age^2
base <- rep(Baseline,rep(4,59))
base2 <- base^2
id <- gl(59,4,236)
times <- gl(4,1,236)

if(interactive()){
postscript("epilepti.eps",height=5)
par(mfrow=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(seq(0,8,by=2),c(Baseline[1]/4,W2[1],W4[1],W6[1],W8[1]),type="l",
	ylim=c(0,100),xlab="Week",ylab="Epileptic seizures",main="Placebo")
for(i in 2:28)lines(seq(0,8,by=2),c(Baseline[i]/4,W2[i],W4[i],W6[i],W8[i]))
plot(seq(0,8,by=2),c(Baseline[29]/4,W2[29],W4[29],W6[29],W8[29]),type="l",
	ylim=c(0,100),xlab="Week",ylab="",main="Progabide")
for(i in 30:59)lines(seq(0,8,by=2),c(Baseline[i]/4,W2[i],W4[i],W6[i],W8[i]))
dev.off()
}

zs <- glm(y~id*times,family=poisson)
zs$aic/2
print(summary(z0 <- glm(y~base+base2+age+age2+base:age+treatment*base,
	family=poisson)))
z0$aic/2
print(z1 <- update(z0,.~.+y1))
z1$aic/2
print(z2 <- update(z1,.~.+y1*(base+treatment)))
z2$aic/2
print(z3 <- update(z2,.~.+id))
z3$aic/2
kalcount(reps,mu=~Baseline*Age,pinit=3.7,preg=c(-1,0.008,0.02,-0.0014),
	dep="frailty")
kalcount(reps,mu=~Baseline*Age+lag1,pinit=3.5,
	ptvc=c(-0.96,0.008,0.029,0.002,-0.0014),dep="frailty")
print(summary(z0a <- glmm(y~base+base2+age+age2+base:age+treatment*base,
	family=poisson,nest=id,points=3)))
z0a$aic/2
print(summary(z1a <- glmm(y~base+base2+age+age2+base:age+treatment*base+y1,
	family=poisson,nest=id,points=3)))
z1a$aic/2
print(summary(z2a <- glmm(y~base+base2+age+age2+base:age+treatment*base+
	y1*(base+treatment),family=poisson,nest=id,points=3)))
z2a$aic/2

count <- NULL
for(i in 1:59)count <- c(count,cumsum(c(Baseline[i],resp[i,1:3])))

print(z8 <- update(z0,.~.+count*(base+treatment)))
z8$aic/2
