library(gnlm)
library(repeated)

data <- read.list("urinary.dat",skip=3,nl=1)
birth <- list()
for(i in 1:length(data)){
	birth <- c(birth,list(c(0,cumsum(data[[i]])[1:(length(data[[i]])-1)])))
	data[[i]] <- cbind(data[[i]],1:length(data[[i]]))}
treatment <- codes(gl(2,36))
reps <- rmna(data,ccov=tcctomat(treatment),tvcov=tvctomat(birth))

gnlr(reps,dist="binomial",mu=~1/(1+exp(-a)),pmu=1)
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-b*treatment)),pmu=c(1,0))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-c*birth)),pmu=c(1,0))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-b*treatment-c*birth)),pmu=c(1,0,0))
gnlr(reps,dist="binomial",mu=~1/(1+exp(-a-d*times)),pmu=c(1,0))

# fixed effects
print(z <- glm(response~treatment+individuals,family=binomial,data=reps))
z$aic/2

# random effects
gnlmm(reps,dist="binomial",pmu=0.6,psd=0.9)
gnlmm(reps,mu=~treatment,dist="binomial",pmu=c(0.44,0.27),psd=0.5)
gnlmm(reps,mu=~treatment+times,dist="binomial",pmu=c(0.44,0.28,-0.0002),
	psd=0.52)

# autoregression
gar(reps,dist="binomial",mu=~1,pdep=0.5,preg=1)
print(zar <- gar(reps,dist="binomial",mu=~1/(1+exp(-a-b*treatment)),
	pdep=0.1,preg=c(2,0)))
gar(reps,dist="binomial",mu=~1/(1+exp(-a-c*birth)),pdep=0.1,preg=c(2,0))
gar(reps,dist="binomial",mu=~1/(1+exp(-a-b*treatment-c*birth)),pdep=0.1,
	preg=c(2,0,0))
gar(reps,dist="binomial",mu=~1/(1+exp(-a-d*times)),pdep=0.1,preg=c(2,0))

if(interactive()){
par(mfrow=c(2,3),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
for(i in 1:3){
      plot(iprofile(zar),nind=i,lty=3)
      plot(mprofile(zar),nind=i,add=T)}
for(i in 37:39){
      plot(iprofile(zar),nind=i,lty=3)
      plot(mprofile(zar),nind=i,add=T)}
}

